@@ -79,8 +79,10 @@ class Engraver:
         self.m_fontsize = 20
         self.m_timepos = timepos
     def get_width(self):
-        # this value will be used for engravers that don't override this method.
-        # FIXME
+        """
+        Get the width of all engravers that does not implement their
+        own get_width function.
+        """
         return 20
     def __str__(self):
         return '(Engraver)'
@@ -154,19 +156,16 @@ class TieEngraver(Engraver):
         self.m_shift2 = shift2
         self.m_ylinepos = ylinepos
     def set_xpos(self, dict):
-        self.m_xpos1 = dict[self.m_pos1].m_music
+        self.m_xpos = dict[self.m_pos1].m_music
         self.m_xpos2 = dict[self.m_pos2].m_music
-        #FIXME the musicdisplayer want every engraver to have a m_xpos to
-        # know how wide the whole music is. Fixthis
-        self.m_xpos = self.m_xpos2
     def engrave(self, widget, gc, staff_yoffset):
         dim = dimentions[self.m_fontsize]
-        self.m_xpos1 += 3 + (self.m_shift1 + 1) * dim.xshift
+        self.m_xpos += 3 + (self.m_shift1 + 1) * dim.xshift
         self.m_xpos2 += - 3 + self.m_shift2 * dim.xshift
-        w = self.m_xpos2 - self.m_xpos1
+        w = self.m_xpos2 - self.m_xpos
         h = 8
         widget.window.draw_arc(gc, False,
-              self.m_xpos1, staff_yoffset + dim.linespacing*(self.m_ylinepos-1)/2 + 3,
+              self.m_xpos, staff_yoffset + dim.linespacing*(self.m_ylinepos-1)/2 + 3,
               w, h, 64 * 180, 64*180)
 
 
@@ -186,7 +185,7 @@ class AccidentalsEngraver(Engraver):
         return self.m_usize
     def engrave(self, widget, gc, staff_yoffset):
         x = 0
-        for y in self.m_accs.keys():
+        for y in self.m_accs:
             for acc in self.m_accs[y]:
                 im = gtk.Image()
                 im.set_from_file(fetadir+'/feta%i-accidentals-%i.xpm' % (self.m_fontsize, acc))
@@ -348,7 +347,7 @@ class TupletEngraver(Engraver):
         widget.window.draw_line(gc, x2, y, self.m_xpos2, y)
         widget.window.draw_line(gc, self.m_xpos1, y, self.m_xpos1, y+5*d)
         widget.window.draw_line(gc, self.m_xpos2, y, self.m_xpos2, y+5*d)
-        #UGH shouldn't we use pango font string to be more portable?
+        #FIXME shouldn't we use pango font string to be more portable?
         font = gtk.load_font("-adobe-helvetica-medium-r-normal-*-12-*-*-*-*-*-*-*")
         widget.window.draw_string(font, gc, m-3, y + 3, str(self.m_den))
 
@@ -406,9 +405,9 @@ class BeamEngraver(Engraver):
         dim = dimentions[self.m_fontsize]
         d = 0
         if self.m_stemdir == const.UP:
-           d = 1
+            d = 1
         else:
-           d = -1
+            d = -1
         x1 = self.m_stems[0].m_xpos
         x2 = self.m_stems[-1].m_xpos
         if self.m_stems[0].m_beamed_stem_top % 2 == 1:
@@ -450,8 +449,8 @@ class BeamEngraver(Engraver):
                     short_beam(self.m_stems[i], dir, yc+1, d)
                     self.m_stems[i]._beam_done = nl
             if self.m_stems[-1].m_mgroup.m_duration.m_nh >= nl \
-                 and self.m_stems[-1]._beam_done <= nl/2:
-                 short_beam(self.m_stems[-1], -1, yc+1, d)
+                    and self.m_stems[-1]._beam_done <= nl/2:
+                short_beam(self.m_stems[-1], -1, yc+1, d)
 
 
 class StemEngraver(Engraver):
