@@ -25,6 +25,7 @@ import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
 
 import gtk, gnome.ui
+import gobject
 import random
 
 import gu, widgets, utils
@@ -46,7 +47,7 @@ class Teacher(abstract.Teacher):
         Return a true value if a new question was created otherwise false.
         """
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
@@ -322,7 +323,7 @@ class Gui(abstract.Gui):
             assert q == Teacher.ERR_CONFIGURE
             self.g_flashbar.flash(_("You have to configure the exercise properly"))
     def on_start_practise(self):
-        gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
+        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New' to begin.")))
         self.g_new.grab_focus()
     def on_end_practise(self):
