@@ -18,14 +18,14 @@
 import os
 
 MAJOR_VERSION = 2
-MINOR_VERSION = 1
-PATCH_LEVEL = 10
+MINOR_VERSION = 2
+PATCH_LEVEL = 0
 VERSION_STRING = '%s.%s.%s' % (MAJOR_VERSION, MINOR_VERSION, PATCH_LEVEL)
-if "no" == "yes":
+if "yes" == "yes":
     WITH_GNOME = 1
 else:
     WITH_GNOME = 0
-WITH_GTKHTML = "no" == 'yes'
+WITH_GTKHTML = "yes" == 'yes'
 prefix = "/usr/local"
 datadir = os.path.join(prefix, "share", "solfege", VERSION_STRING)
 HAVE_LINUX_AWE_VOICE_H = "yes" == "yes"
