@@ -17,6 +17,7 @@
 
 import gtk
 import gnome
+import gobject
 import soundcard
 import cfg
 
@@ -187,7 +188,7 @@ class FlashBar(gtk.Frame):
         we old flashed message are removed.
         """
         if self.__timeout:
-            gtk.timeout_remove(self.__timeout)
+            gobject.source_remove(self.__timeout)
         self.__label.set_text(txt)
         def f(self=self):
             self.__timeout = None
@@ -195,11 +196,11 @@ class FlashBar(gtk.Frame):
                 self.__label.set_text(self.__stack[-1])
             else:
                 self.__label.set_text('')
-        self.__timeout = gtk.timeout_add(2000, f)
+        self.__timeout = gobject.timeout_add(2000, f)
     def push(self, txt):
         # stop any flashing before we push
         if self.__timeout:
-            gtk.timeout_remove(self.__timeout)
+            gobject.source_remove(self.__timeout)
             self.__timeout = None
         self.__stack.append(txt)
         self.__label.set_text(txt, '')
