@@ -24,7 +24,7 @@ __exercise_data__ = {
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
 
-import gtk, gnome.ui
+import gtk, gnome.ui, gobject
 import abstract, const, gu, mpd, soundcard
 import random, os
 import cfg
@@ -54,7 +54,7 @@ class Teacher(abstract.Teacher):
                Teacher.ERR_NO_ELEMS : if no elements are set to be practised.
         """
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
@@ -156,7 +156,7 @@ class RhythmViewer(gtk.Frame):
         create those |__| that represents one beat
         """
         if self.__timeout:
-            gtk.timeout_remove(self.__timeout)
+            gobject.source_remove(self.__timeout)
         self.clear()
         for x in range(self.m_num_beats):
             self.g_box.pack_start(create_png_image('holder'), False)
@@ -239,7 +239,7 @@ class RhythmViewer(gtk.Frame):
         l.set_alignment(0.0, 0.5)
         l.show()
         self.g_box.pack_start(l, True, True)
-        self.__timeout = gtk.timeout_add(const.NORMAL_WAIT, self.unflash)
+        self.__timeout = gobject.timeout_add(const.NORMAL_WAIT, self.unflash)
     def unflash(self, *v):
         self.__timeout = None
         self.clear()
